Writers
=======

.. automodule:: stonesoup.writer
    :no-members:

.. automodule:: stonesoup.writer.base
    :show-inheritance:

YAML
----
.. automodule:: stonesoup.writer.yaml
    :show-inheritance:
